==> owncloud-8.1.0p2.tgz: owncloud/apps/user_ldap/l10n/fa.js <==
OC.L10N.register(
    "user_ldap",
    {
    "Failed to clear the mappings." : "عدم موفقیت در پاک کردن نگاشت.",
    "Failed to delete the server configuration" : "عملیات حذف پیکربندی سرور ناموفق ماند",
    "The configuration is valid and the connection could be established!" : "پیکربندی معتبر است و ارتباط می تواند برقرار شود",
    "The configuration is valid, but the Bind failed. Please check the server settings and credentials." : "پیکربندی معتبراست، اما اتصال شکست خورد. لطفا تنظیمات و اعتبارهای سرور را بررسی کنید.",
    "No action specified" : "فعالیتی مشخص نشده است",
    "No configuration specified" : "هیچ پیکربندی مشخص نشده است",
    "No data specified" : "داده ای مشخص نشده است",
    "Configuration incorrect" : "پیکربندی نادرست است",
    "Configuration incomplete" : "پیکربندی کامل نیست",
    "Configuration OK" : "پیکربندی صحیح است",
    "Select groups" : "انتخاب گروه ها",
    "Select object classes" : "انتخاب کلاس های اشیا",
    "{nthServer}. Server" : "سرور {nthServer}.",
    "Do you really want to delete the current Server Configuration?" : "آیا واقعا می خواهید پیکربندی کنونی سرور را حذف کنید؟",
    "Confirm Deletion" : "تایید حذف",
    "Select attributes" : "انتخاب مشخصه ها",
    "_%s group found_::_%s groups found_" : ["%s گروه بافت شد"],
    "_%s user found_::_%s users found_" : ["%s کاربر بافت شد"],
    "Invalid Host" : "هاست نامعتبر است",
    "Server" : "سرور",
    "Users" : "کاربران",
    "Groups" : "گروه ها",
    "Test Configuration" : "امتحان پیکربندی",
    "Help" : "راه‌نما",
    "Other Attributes:" : "مشخصه های دیگر:",
    "1. Server" : "1. سرور",
    "%s. Server:" : "%s. سرور:",
    "Host" : "میزبانی",
    "Port" : "درگاه",
    "User DN" : "کاربر DN",
    "Password" : "گذرواژه",
    "For anonymous access, leave DN and Password empty." : "برای دسترسی ناشناس، DN را رها نموده و رمزعبور را خالی بگذارید.",
    "One Base DN per line" : "یک پایه DN در هر خط",
    "You can specify Base DN for users and groups in the Advanced tab" : "شما می توانید پایه DN را برای کاربران و گروه ها در زبانه Advanced مشخص کنید.",
    "Back" : "بازگشت",
    "Continue" : "ادامه",
    "Expert" : "حرفه ای",
    "Advanced" : "پیشرفته",
    "Connection Settings" : "تنظیمات اتصال",
    "Configuration Active" : "پیکربندی فعال",
    "When unchecked, this configuration will be skipped." : "زمانیکه انتخاب نشود، این پیکربندی نادیده گرفته خواهد شد.",
    "Backup (Replica) Host" : "پشتیبان گیری (بدل) میزبان",
    "Backup (Replica) Port" : "پشتیبان گیری (بدل) پورت",
    "Disable Main Server" : "غیر فعال کردن سرور اصلی",
    "Turn off SSL certificate validation." : "غیرفعال کردن اعتبار گواهی نامه SSL .",
    "Directory Settings" : "تنظیمات پوشه",
    "User Display Name Field" : "فیلد نام کاربر",
    "Base User Tree" : "کاربر درخت پایه",
    "One User Base DN per line" : "یک کاربر پایه DN در هر خط",
    "User Search Attributes" : "ویژگی های جستجوی کاربر",
    "Optional; one attribute per line" : "اختیاری؛ یک ویژگی در هر خط",
    "Group Display Name Field" : "فیلد نام گروه",
    "Base Group Tree" : "گروه درخت پایه ",
    "One Group Base DN per line" : "یک گروه پایه DN در هر خط",
    "Group Search Attributes" : "گروه صفات جستجو",
    "Group-Member association" : "انجمن گروه کاربران",
    "Special Attributes" : "ویژگی های مخصوص",
    "Quota Field" : "سهمیه بندی انجام نشد.",
    "Quota Default" : "سهمیه بندی پیش فرض",
    "in bytes" : "در بایت",
    "Email Field" : "ایمیل ارسال نشد.",
    "User Home Folder Naming Rule" : "قانون نامگذاری پوشه خانه کاربر",
    "Leave empty for user name (default). Otherwise, specify an LDAP/AD attribute." : "خالی گذاشتن برای نام کاربری (پیش فرض). در غیر این صورت، تعیین یک ویژگی LDAP/AD.",
    "Internal Username" : "نام کاربری داخلی",
    "Internal Username Attribute:" : "ویژگی نام کاربری داخلی:",
    "Override UUID detection" : "نادیده گرفتن تشخیص UUID ",
    "Username-LDAP User Mapping" : "نام کاربری - نگاشت کاربر LDAP ",
    "Clear Username-LDAP User Mapping" : "پاک کردن نام کاربری- LDAP  نگاشت کاربر ",
    "Clear Groupname-LDAP Group Mapping" : "پاک کردن نام گروه -LDAP گروه نقشه برداری"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.3.tgz: owncloud/apps/user_ldap/l10n/fa.js <==
OC.L10N.register(
    "user_ldap",
    {
    "Failed to clear the mappings." : "عدم موفقیت در پاک کردن نگاشت.",
    "Failed to delete the server configuration" : "عملیات حذف پیکربندی سرور ناموفق ماند",
    "The configuration is valid and the connection could be established!" : "پیکربندی معتبر است و ارتباط می تواند برقرار شود",
    "The configuration is valid, but the Bind failed. Please check the server settings and credentials." : "پیکربندی معتبراست، اما اتصال شکست خورد. لطفا تنظیمات و اعتبارهای سرور را بررسی کنید.",
    "No action specified" : "فعالیتی مشخص نشده است",
    "No configuration specified" : "هیچ پیکربندی مشخص نشده است",
    "No data specified" : "داده ای مشخص نشده است",
    "Configuration incorrect" : "پیکربندی نادرست است",
    "Configuration incomplete" : "پیکربندی کامل نیست",
    "Configuration OK" : "پیکربندی صحیح است",
    "Select groups" : "انتخاب گروه ها",
    "Select object classes" : "انتخاب کلاس های اشیا",
    "Please specify the port, it could not be auto-detected." : "لطفا پورت را مشخص کنید، امکان تعیین خودکار وجود ندارد.",
    "Could not detect Base DN, please enter it manually." : "امکان شناسایی Base DN, وجود ندارد، لطفا بصورت دستی آنرا وارد کنید.",
    "{nthServer}. Server" : "سرور {nthServer}.",
    "Do you really want to delete the current Server Configuration?" : "آیا واقعا می خواهید پیکربندی کنونی سرور را حذف کنید؟",
    "Confirm Deletion" : "تایید حذف",
    "Select attributes" : "انتخاب مشخصه ها",
    "_%s group found_::_%s groups found_" : ["%s گروه بافت شد"],
    "_%s user found_::_%s users found_" : ["%s کاربر بافت شد"],
    "Invalid Host" : "هاست نامعتبر است",
    "Server" : "سرور",
    "Users" : "کاربران",
    "Groups" : "گروه ها",
    "Test Configuration" : "امتحان پیکربندی",
    "Help" : "راه‌نما",
    "Only from these groups:" : "تنها از این گروه‌ها:",
    "Search groups" : "جستجوی گروه‌ها",
    "Available groups" : "گروه‌های موجود",
    "Selected groups" : "گروه‌های انتخاب شده",
    "LDAP Filter:" : "فیلتر LDAP:",
    "LDAP / AD Username:" : "نام‌کاربری LDAP / AD :",
    "LDAP / AD Email Address:" : " آدرس ایمیل LDAP / AD :",
    "Other Attributes:" : "مشخصه های دیگر:",
    "1. Server" : "1. سرور",
    "%s. Server:" : "%s. سرور:",
    "Host" : "میزبانی",
    "Port" : "درگاه",
    "Detect Port" : "شناسایی پورت",
    "User DN" : "کاربر DN",
    "Password" : "گذرواژه",
    "For anonymous access, leave DN and Password empty." : "برای دسترسی ناشناس، DN را رها نموده و رمزعبور را خالی بگذارید.",
    "One Base DN per line" : "یک پایه DN در هر خط",
    "You can specify Base DN for users and groups in the Advanced tab" : "شما می توانید پایه DN را برای کاربران و گروه ها در زبانه Advanced مشخص کنید.",
    "Test Base DN" : "تست DN پایه",
    "Saving" : "درحال ذخیره",
    "Back" : "بازگشت",
    "Continue" : "ادامه",
    "LDAP" : "LDAP",
    "Expert" : "حرفه ای",
    "Advanced" : "پیشرفته",
    "Connection Settings" : "تنظیمات اتصال",
    "Configuration Active" : "پیکربندی فعال",
    "When unchecked, this configuration will be skipped." : "زمانیکه انتخاب نشود، این پیکربندی نادیده گرفته خواهد شد.",
    "Backup (Replica) Host" : "پشتیبان گیری (بدل) میزبان",
    "Backup (Replica) Port" : "پشتیبان گیری (بدل) پورت",
    "Disable Main Server" : "غیر فعال کردن سرور اصلی",
    "Turn off SSL certificate validation." : "غیرفعال کردن اعتبار گواهی نامه SSL .",
    "Cache Time-To-Live" : "مدت زمان کش",
    "Directory Settings" : "تنظیمات پوشه",
    "User Display Name Field" : "فیلد نام کاربر",
    "Base User Tree" : "کاربر درخت پایه",
    "One User Base DN per line" : "یک کاربر پایه DN در هر خط",
    "User Search Attributes" : "ویژگی های جستجوی کاربر",
    "Optional; one attribute per line" : "اختیاری؛ یک ویژگی در هر خط",
    "Group Display Name Field" : "فیلد نام گروه",
    "Base Group Tree" : "گروه درخت پایه ",
    "One Group Base DN per line" : "یک گروه پایه DN در هر خط",
    "Group Search Attributes" : "گروه صفات جستجو",
    "Group-Member association" : "انجمن گروه کاربران",
    "Nested Groups" : "گروه‌های زیرمجموعه",
    "Special Attributes" : "ویژگی های مخصوص",
    "Quota Field" : "سهمیه بندی انجام نشد.",
    "Quota Default" : "سهمیه بندی پیش فرض",
    "in bytes" : "در بایت",
    "Email Field" : "ایمیل ارسال نشد.",
    "User Home Folder Naming Rule" : "قانون نامگذاری پوشه خانه کاربر",
    "Leave empty for user name (default). Otherwise, specify an LDAP/AD attribute." : "خالی گذاشتن برای نام کاربری (پیش فرض). در غیر این صورت، تعیین یک ویژگی LDAP/AD.",
    "Internal Username" : "نام کاربری داخلی",
    "Internal Username Attribute:" : "ویژگی نام کاربری داخلی:",
    "Override UUID detection" : "نادیده گرفتن تشخیص UUID ",
    "UUID Attribute for Users:" : "UUID ویژگی‌ برای کاربران:",
    "Username-LDAP User Mapping" : "نام کاربری - نگاشت کاربر LDAP ",
    "Clear Username-LDAP User Mapping" : "پاک کردن نام کاربری- LDAP  نگاشت کاربر ",
    "Clear Groupname-LDAP Group Mapping" : "پاک کردن نام گروه -LDAP گروه نقشه برداری",
    "{nthServer}. Server" : "سرور {nthServer}."
},
"nplurals=1; plural=0;");
